==> opsdroid-0.7.1.tar.gz: opsdroid-0.7.1/opsdroid/web.py <==
"""Submodule to handle web requests in opsdroid."""

import json
import logging

from aiohttp import web

from opsdroid.const import __version__


_LOGGER = logging.getLogger(__name__)


class Web:
    """Web server for opsdroid."""

    def __init__(self, opsdroid):
        """Setup web object."""
        self.opsdroid = opsdroid
        try:
            self.config = self.opsdroid.config["web"]
        except KeyError:
            self.config = {}
        self.web_app = web.Application(loop=self.opsdroid.eventloop)
        self.web_app.router.add_get('/', self.web_index_handler)
        self.web_app.router.add_get('', self.web_index_handler)
        self.web_app.router.add_get('/stats', self.web_stats_handler)
        self.web_app.router.add_get('/stats/', self.web_stats_handler)

    @property
    def get_port(self):
        """Return port from config or the default."""
        try:
            port = self.config["port"]
        except KeyError:
            port = 8080
        return port

    @property
    def get_host(self):
        """Return host from config or the default."""
        try:
            host = self.config["host"]
        except KeyError:
            host = '127.0.0.1'
        return host

    def start(self):
        """Start web servers."""
        _LOGGER.debug(
            "Starting web server with host %s and port %s",
            self.get_host, self.get_port)
        web.run_app(self.web_app, host=self.get_host,
                    port=self.get_port, print=_LOGGER.info)

    @staticmethod
    def build_response(status, result):
        """Build a json response object."""
        return web.Response(text=json.dumps(result), status=status)

    def web_index_handler(self, request):
        """Handle root web request."""
        return self.build_response(200, {
            "message": "Welcome to the opsdroid API"})

    def web_stats_handler(self, request):
        """Handle stats request."""
        stats = self.opsdroid.stats
        try:
            stats["average_response_time"] = \
                stats["total_response_time"] / stats["total_responses"]
        except ZeroDivisionError:
            stats["average_response_time"] = 0

        return self.build_response(200, {
            "version": __version__,
            "messages": {
                "total_parsed": stats["messages_parsed"],
                "webhooks_called": stats["webhooks_called"],
                "total_response_time": stats["total_response_time"],
                "total_responses": stats["total_responses"],
                "average_response_time": stats["average_response_time"]
            },
            "modules": {
                "skills": len(self.opsdroid.skills),
                "connectors": len(self.opsdroid.connectors),
                "databases": len(self.opsdroid.memory.databases)
            }
        })

==> opsdroid-0.8.1.tar.gz: opsdroid-0.8.1/opsdroid/web.py <==
"""Submodule to handle web requests in opsdroid."""

import json
import logging

from aiohttp import web

from opsdroid.const import __version__


_LOGGER = logging.getLogger(__name__)


class Web:
    """Web server for opsdroid."""

    def __init__(self, opsdroid):
        """Create web object."""
        self.opsdroid = opsdroid
        try:
            self.config = self.opsdroid.config["web"]
        except KeyError:
            self.config = {}
        self.web_app = web.Application(loop=self.opsdroid.eventloop)
        self.web_app.router.add_get('/', self.web_index_handler)
        self.web_app.router.add_get('', self.web_index_handler)
        self.web_app.router.add_get('/stats', self.web_stats_handler)
        self.web_app.router.add_get('/stats/', self.web_stats_handler)

    @property
    def get_port(self):
        """Return port from config or the default."""
        try:
            port = self.config["port"]
        except KeyError:
            port = 8080
        return port

    @property
    def get_host(self):
        """Return host from config or the default."""
        try:
            host = self.config["host"]
        except KeyError:
            host = '127.0.0.1'
        return host

    def start(self):
        """Start web servers."""
        _LOGGER.debug(
            "Starting web server with host %s and port %s",
            self.get_host, self.get_port)
        web.run_app(self.web_app, host=self.get_host,
                    port=self.get_port, print=_LOGGER.info)

    @staticmethod
    def build_response(status, result):
        """Build a json response object."""
        return web.Response(text=json.dumps(result), status=status)

    def web_index_handler(self, request):
        """Handle root web request."""
        return self.build_response(200, {
            "message": "Welcome to the opsdroid API"})

    def web_stats_handler(self, request):
        """Handle stats request."""
        stats = self.opsdroid.stats
        try:
            stats["average_response_time"] = \
                stats["total_response_time"] / stats["total_responses"]
        except ZeroDivisionError:
            stats["average_response_time"] = 0

        return self.build_response(200, {
            "version": __version__,
            "messages": {
                "total_parsed": stats["messages_parsed"],
                "webhooks_called": stats["webhooks_called"],
                "total_response_time": stats["total_response_time"],
                "total_responses": stats["total_responses"],
                "average_response_time": stats["average_response_time"]
            },
            "modules": {
                "skills": len(self.opsdroid.skills),
                "connectors": len(self.opsdroid.connectors),
                "databases": len(self.opsdroid.memory.databases)
            }
        })
